@@ -3,7 +3,7 @@ use 5.006;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '0.003000';
+our $VERSION = '0.003001';
 $VERSION = eval $VERSION;
 
 use Carp ();
@@ -132,6 +132,7 @@ sub CLONE {
 }
 
 sub _convert {
+  __PACKAGE__->CLONE;
   if (my $class = blessed $_[0]) {
     return @_
       unless $options{objects};
@@ -140,7 +141,7 @@ sub _convert {
     return @_
       if $attached{$id};
 
-    my $does = $ex->can('DOES') || sub () { 0 };
+    my $does = $ex->can('does') || $ex->can('DOES') || sub () { 0 };
     if (
       grep {
         $NoTrace{$_}
@@ -216,6 +217,9 @@ sub _convert {
 my $_ex_info = sub {
   @{$attached{refaddr $_[0]}};
 };
+my $_delete_ex_info = sub {
+  @{ delete $attached{refaddr $_[0]} };
+};
 
 {
   package #hide
@@ -234,7 +238,7 @@ my $_ex_info = sub {
       my ($ex, $class) = $_ex_info->(@_);
       my $newclass = ref $ex;
       bless $ex, $class;
-      my $out = 0+$ex;
+      my $out = 0+sprintf '%f', $ex;
       bless $ex, $newclass;
       return $out;
     },
@@ -249,7 +253,7 @@ my $_ex_info = sub {
   ;
 
   sub DESTROY {
-    my ($ex, $class) = $_ex_info->(@_);
+    my ($ex, $class) = $_delete_ex_info->(@_);
     my $newclass = ref $ex;
 
     Symbol::delete_package($newclass);
